@@ -716,8 +716,10 @@ class Client(object):
             # always safe - namely not for Cryosat or other ESA datasets.
             filename = None
 
-        if download_dir is None or not os.path.exists(download_dir):
+        if download_dir is None:
             download_dir = "."
+        else:
+            os.makedirs(download_dir, exist_ok=True)
 
         logger.info(
             "Downloading %s to %s (%s)",
